@@ -1,4 +1,4 @@
-from . import run_app
+from ts_app import run_app
 
 
 if __name__ == '__main__':
