@@ -2,8 +2,10 @@ import dash_core_components as dcc
 import dash_html_components as html
 from dash.dependencies import Input, Output
 from ts_app.dash_app import app
-from ts_app.dashboards import sample_dashboard, model_dashboard
 from ts_app.dashboards.dashboard_resources import template
+from ts_app.dashboards import (
+    home_page, glossary, sample_dashboard, upload_dashboard
+)
 
 
 app.index_string = template
@@ -28,10 +30,14 @@ def display_page(path_name):
     ----------
     path_name: str
     """
-    if path_name == '/dashboard/upload':
-        return model_dashboard.layout
-    else:
+    if path_name == '/upload':
+        return upload_dashboard.layout
+    elif path_name == '/sample':
         return sample_dashboard.layout
+    elif path_name == '/glossary':
+        return glossary.layout
+    else:
+        return home_page.layout
 
 
 if __name__ == '__main__':
